@@ -12,10 +12,9 @@ Other API requests are available, such as exporting users & Form-Event Mappings.
 
 """
 
-from .project import Project
-from .request import RCRequest, RCAPIError, RedcapError
+from redcap.project import Project
+from redcap.request import _RCRequest, RedcapError
 
 __author__ = "Scott Burns <scott.s.burns@gmail.com>"
 __license__ = "MIT"
 __copyright__ = "2014, Vanderbilt University"
-__version__ = "1.1.3"
