@@ -1,8 +1,10 @@
 """Make the method modules available upon import"""
 
+import redcap.methods.data_access_groups
 import redcap.methods.field_names
 import redcap.methods.files
 import redcap.methods.instruments
+import redcap.methods.logging
 import redcap.methods.metadata
 import redcap.methods.project_info
 import redcap.methods.records
@@ -10,4 +12,5 @@ import redcap.methods.repeating
 import redcap.methods.reports
 import redcap.methods.surveys
 import redcap.methods.users
+import redcap.methods.user_roles
 import redcap.methods.version
