@@ -27,11 +27,13 @@ class Records(Base):
         record_type: Literal["flat", "eav"] = "flat",
         export_survey_fields: bool = False,
         export_data_access_groups: bool = False,
-        df_kwargs: Optional[Dict[str, Any]] = None,
         export_checkbox_labels: bool = False,
         filter_logic: Optional[str] = None,
         date_begin: Optional[datetime] = None,
         date_end: Optional[datetime] = None,
+        decimal_character: Optional[Literal[",", "."]] = None,
+        export_blank_for_gray_form_status: Optional[bool] = None,
+        df_kwargs: Optional[Dict[str, Any]] = None,
     ) -> Json:
         ...
 
@@ -49,11 +51,13 @@ class Records(Base):
         record_type: Literal["flat", "eav"] = "flat",
         export_survey_fields: bool = False,
         export_data_access_groups: bool = False,
-        df_kwargs: Optional[Dict[str, Any]] = None,
         export_checkbox_labels: bool = False,
         filter_logic: Optional[str] = None,
         date_begin: Optional[datetime] = None,
         date_end: Optional[datetime] = None,
+        decimal_character: Optional[Literal[",", "."]] = None,
+        export_blank_for_gray_form_status: Optional[bool] = None,
+        df_kwargs: Optional[Dict[str, Any]] = None,
     ) -> str:
         ...
 
@@ -71,11 +75,13 @@ class Records(Base):
         record_type: Literal["flat", "eav"] = "flat",
         export_survey_fields: bool = False,
         export_data_access_groups: bool = False,
-        df_kwargs: Optional[Dict[str, Any]] = None,
         export_checkbox_labels: bool = False,
         filter_logic: Optional[str] = None,
         date_begin: Optional[datetime] = None,
         date_end: Optional[datetime] = None,
+        decimal_character: Optional[Literal[",", "."]] = None,
+        export_blank_for_gray_form_status: Optional[bool] = None,
+        df_kwargs: Optional[Dict[str, Any]] = None,
     ) -> "pd.DataFrame":
         ...
 
@@ -92,11 +98,13 @@ class Records(Base):
         record_type: Literal["flat", "eav"] = "flat",
         export_survey_fields: bool = False,
         export_data_access_groups: bool = False,
-        df_kwargs: Optional[Dict[str, Any]] = None,
         export_checkbox_labels: bool = False,
         filter_logic: Optional[str] = None,
         date_begin: Optional[datetime] = None,
         date_end: Optional[datetime] = None,
+        decimal_character: Optional[Literal[",", "."]] = None,
+        export_blank_for_gray_form_status: Optional[bool] = None,
+        df_kwargs: Optional[Dict[str, Any]] = None,
     ):
         # pylint: disable=line-too-long
         """
@@ -146,10 +154,6 @@ class Records(Base):
                     being used to make the API request is *not* in a data
                     access group. If the user is in a group, then this flag
                     will revert to its default value.
-            df_kwargs:
-                Passed to `pandas.read_csv` to control construction of
-                returned DataFrame.
-                By default, `{'index_col': self.def_field}`
             export_checkbox_labels:
                 Specify whether to export checkbox values as their label on
                 export.
@@ -159,7 +163,15 @@ class Records(Base):
                 Filter on records created after a date
             date_end:
                 Filter on records created before a date
-
+            decimal_character:
+                Force all numbers into same decimal format
+            export_blank_for_gray_form_status:
+                Whether or not to export blank values for instrument complete status fields
+                that have a gray status icon
+            df_kwargs:
+                Passed to `pandas.read_csv` to control construction of
+                returned DataFrame.
+                By default, `{'index_col': self.def_field}`
         Returns:
             Union[List[Dict[str, Any]], str, pd.DataFrame]: Exported data
 
@@ -211,6 +223,9 @@ class Records(Base):
             export_survey_fields,
             export_data_access_groups,
             export_checkbox_labels,
+            filter_logic,
+            decimal_character,
+            export_blank_for_gray_form_status,
         )
 
         str_keys = (
@@ -224,6 +239,9 @@ class Records(Base):
             "exportSurveyFields",
             "exportDataAccessGroups",
             "exportCheckboxLabel",
+            "filterLogic",
+            "decimalCharacter",
+            "exportBlankForGrayFormStatus",
         )
 
         for key, data in zip(str_keys, keys_to_add):
@@ -240,9 +258,6 @@ class Records(Base):
         if date_end:
             payload["dateRangeEnd"] = date_end.strftime("%Y-%m-%d %H:%M:%S")
 
-        if filter_logic:
-            payload["filterLogic"] = filter_logic
-
         return_type = self._lookup_return_type(format_type, request_type="export")
         response = self._call_api(payload, return_type)
 
@@ -372,13 +387,10 @@ class Records(Base):
             return_format_type=return_format_type,
             content="record",
         )
-
-        # pylint: disable=unsupported-assignment-operation
         payload["overwriteBehavior"] = overwrite
         payload["returnContent"] = return_content
         payload["dateFormat"] = date_format
         payload["forceAutoNumber"] = force_auto_number
-        # pylint: enable=unsupported-assignment-operation
 
         return_type = self._lookup_return_type(
             format_type=return_format_type,
@@ -411,6 +423,8 @@ class Records(Base):
 
         Args:
             records: List of record IDs to delete from the project
+            return_format_type:
+                Response format. By default, response will be json-decoded.
 
         Returns:
             Union[int, str]: Number of records deleted
