@@ -19,9 +19,11 @@ __copyright__ = "2014, Vanderbilt University"
 
 
 class Project(
+    methods.data_access_groups.DataAccessGroups,
     methods.field_names.FieldNames,
     methods.files.Files,
     methods.instruments.Instruments,
+    methods.logging.Logging,
     methods.metadata.Metadata,
     methods.project_info.ProjectInfo,
     methods.records.Records,
@@ -29,6 +31,7 @@ class Project(
     methods.reports.Reports,
     methods.surveys.Surveys,
     methods.users.Users,
+    methods.user_roles.UserRoles,
     methods.version.Version,
 ):
     """Main class for interacting with REDCap projects
@@ -69,5 +72,10 @@ class Project(
         try:
             return self._redcap_version
         except AttributeError:
+            # weird pylint bug on windows where it can't find Version.export_version()
+            # possible too many parents it's inheriting from? We also need to disable
+            # useless-supression since this is a windows only issue
+            # pylint: disable=no-member,useless-suppression
             self._redcap_version = self.export_version()
+            # pylint: enable=no-member,useless-suppression
             return self._redcap_version
